otel

package module
v0.3.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 23, 2026 License: MIT Imports: 9 Imported by: 0

Documentation

Overview

Package otel converts selected OpenTelemetry spans into correlated webpprof requests, queries, cache operations, jobs, HTTP calls, and custom events.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewSpanProcessor

func NewSpanProcessor(profiler *webpprof.Profiler) sdktrace.SpanProcessor

NewSpanProcessor returns a processor that mirrors supported ended spans into profiler. A nil profiler returns nil.

func Profile

func Profile(provider *sdktrace.TracerProvider) *sdktrace.TracerProvider

Profile instruments provider with the default profiler.

func ProfileWith

func ProfileWith(profiler *webpprof.Profiler, provider *sdktrace.TracerProvider) *sdktrace.TracerProvider

ProfileWith instruments provider with an explicit profiler.

func SpanProcessor

func SpanProcessor() sdktrace.SpanProcessor

SpanProcessor returns a processor for the default profiler, or nil when no profiler is active.

Types

type ProfilerOTel

type ProfilerOTel struct{}

ProfilerOTel implements webpprof.Integration for SDK tracer providers.

func New

func New() ProfilerOTel

New creates an OpenTelemetry tracer-provider integration.

func (ProfilerOTel) Name

func (ProfilerOTel) Name() string

Name returns the integration cache namespace.

func (ProfilerOTel) Profile

Profile registers one span processor on provider for the current profiler scope. Repeated calls for the same provider are idempotent.

Jump to