Documentation
¶
Overview ¶
Package asynq profiles Asynq enqueue and worker execution operations while keeping Asynq and Redis dependencies outside the webpprof core module.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Middleware ¶
func Middleware(configs ...Config) asynq.MiddlewareFunc
Middleware profiles worker execution. Register it with ServeMux.Use.
func MiddlewareWith ¶
func MiddlewareWith(p *webpprof.Profiler, configs ...Config) asynq.MiddlewareFunc
MiddlewareWith profiles worker execution with p.
Types ¶
type Client ¶
type Client interface {
Enqueue(*asynq.Task, ...asynq.Option) (*asynq.TaskInfo, error)
EnqueueContext(context.Context, *asynq.Task, ...asynq.Option) (*asynq.TaskInfo, error)
}
Client is the subset of asynq.Client wrapped by Profile. Keep the original *asynq.Client to call Close; ownership is not transferred to this wrapper.
Click to show internal directories.
Click to hide internal directories.