Documentation
¶
Overview ¶
Package grpc provides server and client interceptors for profiling gRPC calls without adding the gRPC dependency to the webpprof core module.
Index ¶
- func ServiceMethod(fullMethod string) (service, method string)
- func StreamClientInterceptor() googlegrpc.StreamClientInterceptor
- func StreamClientInterceptorWith(p *webpprof.Profiler) googlegrpc.StreamClientInterceptor
- func StreamServerInterceptor() googlegrpc.StreamServerInterceptor
- func StreamServerInterceptorWith(p *webpprof.Profiler) googlegrpc.StreamServerInterceptor
- func UnaryClientInterceptor() googlegrpc.UnaryClientInterceptor
- func UnaryClientInterceptorWith(p *webpprof.Profiler) googlegrpc.UnaryClientInterceptor
- func UnaryServerInterceptor() googlegrpc.UnaryServerInterceptor
- func UnaryServerInterceptorWith(p *webpprof.Profiler) googlegrpc.UnaryServerInterceptor
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ServiceMethod ¶
ServiceMethod splits a full gRPC method into service and method names.
func StreamClientInterceptor ¶
func StreamClientInterceptor() googlegrpc.StreamClientInterceptor
StreamClientInterceptor profiles a streaming client call when the stream finishes, or immediately when stream creation fails.
func StreamClientInterceptorWith ¶
func StreamClientInterceptorWith(p *webpprof.Profiler) googlegrpc.StreamClientInterceptor
StreamClientInterceptorWith profiles streaming client calls with p.
func StreamServerInterceptor ¶
func StreamServerInterceptor() googlegrpc.StreamServerInterceptor
StreamServerInterceptor profiles streaming server calls as webpprof requests.
func StreamServerInterceptorWith ¶
func StreamServerInterceptorWith(p *webpprof.Profiler) googlegrpc.StreamServerInterceptor
StreamServerInterceptorWith profiles streaming server calls with p.
func UnaryClientInterceptor ¶
func UnaryClientInterceptor() googlegrpc.UnaryClientInterceptor
UnaryClientInterceptor profiles unary client calls as outgoing HTTP-call entities. The Method value is GRPC and URL contains the full RPC method.
func UnaryClientInterceptorWith ¶
func UnaryClientInterceptorWith(p *webpprof.Profiler) googlegrpc.UnaryClientInterceptor
UnaryClientInterceptorWith profiles unary client calls with p.
func UnaryServerInterceptor ¶
func UnaryServerInterceptor() googlegrpc.UnaryServerInterceptor
UnaryServerInterceptor profiles unary server calls as webpprof requests.
func UnaryServerInterceptorWith ¶
func UnaryServerInterceptorWith(p *webpprof.Profiler) googlegrpc.UnaryServerInterceptor
UnaryServerInterceptorWith profiles unary server calls with p.
Types ¶
This section is empty.