Documentation
¶
Overview ¶
Package pgx profiles native pgx queries without routing them through database/sql.
Index ¶
- func ProfileConfig(config *pgx.ConnConfig, configs ...Config) *pgx.ConnConfig
- func ProfileConfigWith(profiler *webpprof.Profiler, config *pgx.ConnConfig, configs ...Config) *pgx.ConnConfig
- func ProfilePoolConfig(config *pgxpool.Config, configs ...Config) *pgxpool.Config
- func ProfilePoolConfigWith(profiler *webpprof.Profiler, config *pgxpool.Config, configs ...Config) *pgxpool.Config
- type Config
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ProfileConfig ¶
func ProfileConfig(config *pgx.ConnConfig, configs ...Config) *pgx.ConnConfig
ProfileConfig returns a copy of config with the default profiler tracer appended. Existing pgx tracers remain active.
func ProfileConfigWith ¶
func ProfileConfigWith(profiler *webpprof.Profiler, config *pgx.ConnConfig, configs ...Config) *pgx.ConnConfig
ProfileConfigWith returns a copy of config with profiler attached. The original config is never mutated.
func ProfilePoolConfig ¶
ProfilePoolConfig returns a copy of a pgxpool config with native query tracing attached to its connection config.
Types ¶
Click to show internal directories.
Click to hide internal directories.